pub struct LintMessage {
pub path: Option<String>,
pub line: Option<usize>,
pub char: Option<usize>,
pub code: String,
pub severity: LintSeverity,
pub name: String,
pub description: Option<String>,
pub original: Option<String>,
pub replacement: Option<String>,
}Expand description
Represents a single lint message. This version of the struct is used as the canonical protocol representation, intended to be serialized directly into JSON.
Fields
path: Option<String>Path to the file this lint message pertains to.
This can either be an absolute path, or relative to the current working
directory when lintrunner was invoked.
When the path is None, this message will be displayed as a general linter error.
line: Option<usize>The line number that the lint message pertains to.
char: Option<usize>The column number that the lint message pertains to.
code: StringLinter code (e.g. FLAKE8). Must match the code specified in the linter config.
severity: LintSeverityThe severity of the lint message.
name: StringThe name of the type of lint message, e.g. “syntax error”
description: Option<String>A more substantive description of the lint message. This can include suggestions for remediation, links to further documentation, etc.
original: Option<String>The original text of the entire file, encoded as a utf-8 string.
replacement: Option<String>If a fix was suggested, this is the replacement text of the entire file, encoded as a utf-8 string.